@@ -102,15 +102,11 @@ class MocketHTTPretty:
 
     Response = Response
 
-    def __init__(self):
-        pass
-
     def __getattr__(self, name):
         if name == "last_request":
-            last_request = getattr(Mocket, "last_request")()
-            return last_request
+            return Mocket.last_request()
         if name == "latest_requests":
-            return getattr(Mocket, "_requests")
+            return Mocket.request_list()
         return getattr(Entry, name)
 
 
